var servicecom_1_1sun_1_1star_1_1configuration_1_1UpdateRootElement =
[
    [ "AccessRootElement", "servicecom_1_1sun_1_1star_1_1configuration_1_1UpdateRootElement.html#a86b09612c8ccba4ac31fd75522c0b4ef", null ],
    [ "com::sun::star::util::XChangesBatch", "servicecom_1_1sun_1_1star_1_1configuration_1_1UpdateRootElement.html#abde407b1523e02e96545eec00a8ea29d", null ]
];